==> keyclic_sdk_api-2.10.1-beta1.tar.gz: lib/model/review_links_author_iri_template.dart <==
part of keyclic_sdk_api.api;

class ReviewLinksAuthorIriTemplate {
  ReviewLinksAuthorIriTemplate({
    this.mapping,
  });

  factory ReviewLinksAuthorIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return ReviewLinksAuthorIriTemplate(
      mapping:
          AssignmentLinksCreatedByIriTemplateMapping.fromJson(json['mapping']),
    );
  }

  AssignmentLinksCreatedByIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is ReviewLinksAuthorIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<ReviewLinksAuthorIriTemplate> listFromJson(List<dynamic> json) {
    return json
            ?.map(
                (dynamic value) => ReviewLinksAuthorIriTemplate.fromJson(value))
            ?.toList() ??
        <ReviewLinksAuthorIriTemplate>[];
  }

  static Map<String, ReviewLinksAuthorIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    return json?.map<String, ReviewLinksAuthorIriTemplate>(
            (String key, dynamic value) {
          return MapEntry(key, ReviewLinksAuthorIriTemplate.fromJson(value));
        }) ??
        <String, ReviewLinksAuthorIriTemplate>{};
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping.toJson(),
    };
  }

  @override
  String toString() {
    return 'ReviewLinksAuthorIriTemplate[mapping=$mapping, ]';
  }
}

==> keyclic_sdk_api-2.13.9-beta1.tar.gz: lib/model/review_links_author_iri_template.dart <==
part of keyclic_sdk_api.api;

class ReviewLinksAuthorIriTemplate {
  ReviewLinksAuthorIriTemplate({
    this.mapping,
  });

  factory ReviewLinksAuthorIriTemplate.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return ReviewLinksAuthorIriTemplate(
      mapping: ContributionLinksContributorIriTemplateMapping.fromJson(
          json['mapping']),
    );
  }

  ContributionLinksContributorIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is ReviewLinksAuthorIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<ReviewLinksAuthorIriTemplate> listFromJson(List<dynamic> json) {
    return json
            ?.map(
                (dynamic value) => ReviewLinksAuthorIriTemplate.fromJson(value))
            ?.toList() ??
        <ReviewLinksAuthorIriTemplate>[];
  }

  static Map<String, ReviewLinksAuthorIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    return json?.map<String, ReviewLinksAuthorIriTemplate>(
            (String key, dynamic value) {
          return MapEntry(key, ReviewLinksAuthorIriTemplate.fromJson(value));
        }) ??
        <String, ReviewLinksAuthorIriTemplate>{};
  }

  Map<String, dynamic> toJson() {
    return {
      'mapping': mapping?.toJson(),
    };
  }

  @override
  String toString() {
    return 'ReviewLinksAuthorIriTemplate[mapping=$mapping, ]';
  }
}
